@@ -205,7 +205,9 @@ class ChartDataViewContextTests(BaseSuperuserAuthenticatedClient):
         self.assertEqual(
             context,
             {
-                "error": "You have no permission to view this chart. Check if you are logged in",
+                "error": "You have no permission to view this chart. "
+                "Check if you are logged in and have permission "
+                "'admin_tools_stats | dashboard stats | Can view dashboard stats'",
                 "graph_title": "Users chart",
                 "view": chart_data_view,
             },
